==> stylish-haskell-0.14.4.0-21-x86_64.pkg.tar.zst: usr/share/haskell/register/stylish-haskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stylish-haskell
version:              0.14.4.0
visibility:           public
id:                   stylish-haskell-0.14.4.0-2Hx3LkRxwplCwiYzHuhjRl
key:                  stylish-haskell-0.14.4.0-2Hx3LkRxwplCwiYzHuhjRl
license:              BSD-3-Clause
copyright:            2012 Jasper Van der Jeugt
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             https://github.com/haskell/stylish-haskell
synopsis:             Haskell code prettifier
description:
    A Haskell code prettifier. For more information, see:

    <https://github.com/haskell/stylish-haskell/blob/master/README.markdown>

category:             Language
abi:                  48971b81a07f11722e0ecfededb4b2c4
exposed:              True
exposed-modules:
    Language.Haskell.Stylish Language.Haskell.Stylish.Config
    Language.Haskell.Stylish.GHC Language.Haskell.Stylish.Module
    Language.Haskell.Stylish.Parse Language.Haskell.Stylish.Printer
    Language.Haskell.Stylish.Step Language.Haskell.Stylish.Step.Data
    Language.Haskell.Stylish.Step.Imports
    Language.Haskell.Stylish.Step.LanguagePragmas
    Language.Haskell.Stylish.Step.ModuleHeader
    Language.Haskell.Stylish.Step.SimpleAlign
    Language.Haskell.Stylish.Step.Squash
    Language.Haskell.Stylish.Step.Tabs
    Language.Haskell.Stylish.Step.TrailingWhitespace
    Language.Haskell.Stylish.Step.UnicodeSyntax

hidden-modules:
    Language.Haskell.Stylish.Align Language.Haskell.Stylish.Block
    Language.Haskell.Stylish.Comments
    Language.Haskell.Stylish.Config.Cabal
    Language.Haskell.Stylish.Config.Internal
    Language.Haskell.Stylish.Editor Language.Haskell.Stylish.Ordering
    Language.Haskell.Stylish.Util Language.Haskell.Stylish.Verbose
    Paths_stylish_haskell

import-dirs:          /usr/lib/ghc-9.4.8/site-local/stylish-haskell-0.14.4.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stylish-haskell-0.14.4.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stylish-haskell-0.14.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stylish-haskell
hs-libraries:         HSstylish-haskell-0.14.4.0-2Hx3LkRxwplCwiYzHuhjRl
depends:
    Cabal-3.8.1.0 HsYAML-0.2.1.3-29vEQ31y4k8Aj5xE3kbzDk
    HsYAML-aeson-0.2.0.1-900X2LOs6qtCADdWJlKesc
    aeson-2.1.2.1-LDBL5bcX1HC79scYyh3opi base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    file-embed-0.0.15.0-7OnjuFj6gBM9fqBKJCVXdU filepath-1.4.2.2
    ghc-9.4.8 ghc-boot-9.4.8 ghc-boot-th-9.4.8
    ghc-lib-parser-ex-9.4.0.0-EjBgET6kF2UDiMbzNpqxUJ mtl-2.2.2
    regex-tdfa-1.3.2.4-4spaPYpacr92ooLlQb3epN
    syb-0.7.2.4-7bSc04XXCdy5oWDf8UOHZs text-2.0.2

haddock-interfaces:   /usr/share/doc/stylish-haskell/html/stylish-haskell.haddock
haddock-html:         /usr/share/doc/stylish-haskell/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> stylish-haskell-0.14.4.0-27-x86_64.pkg.tar.zst: usr/share/haskell/register/stylish-haskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stylish-haskell
version:              0.14.4.0
visibility:           public
id:                   stylish-haskell-0.14.4.0-E4GUi076jbH3gvW4A0pAPp
key:                  stylish-haskell-0.14.4.0-E4GUi076jbH3gvW4A0pAPp
license:              BSD-3-Clause
copyright:            2012 Jasper Van der Jeugt
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             https://github.com/haskell/stylish-haskell
synopsis:             Haskell code prettifier
description:
    A Haskell code prettifier. For more information, see:

    <https://github.com/haskell/stylish-haskell/blob/master/README.markdown>

category:             Language
abi:                  55de48a673ee86073b2187093831e564
exposed:              True
exposed-modules:
    Language.Haskell.Stylish Language.Haskell.Stylish.Config
    Language.Haskell.Stylish.GHC Language.Haskell.Stylish.Module
    Language.Haskell.Stylish.Parse Language.Haskell.Stylish.Printer
    Language.Haskell.Stylish.Step Language.Haskell.Stylish.Step.Data
    Language.Haskell.Stylish.Step.Imports
    Language.Haskell.Stylish.Step.LanguagePragmas
    Language.Haskell.Stylish.Step.ModuleHeader
    Language.Haskell.Stylish.Step.SimpleAlign
    Language.Haskell.Stylish.Step.Squash
    Language.Haskell.Stylish.Step.Tabs
    Language.Haskell.Stylish.Step.TrailingWhitespace
    Language.Haskell.Stylish.Step.UnicodeSyntax

hidden-modules:
    Language.Haskell.Stylish.Align Language.Haskell.Stylish.Block
    Language.Haskell.Stylish.Comments
    Language.Haskell.Stylish.Config.Cabal
    Language.Haskell.Stylish.Config.Internal
    Language.Haskell.Stylish.Editor Language.Haskell.Stylish.Ordering
    Language.Haskell.Stylish.Util Language.Haskell.Stylish.Verbose
    Paths_stylish_haskell

import-dirs:          /usr/lib/ghc-9.4.8/site-local/stylish-haskell-0.14.4.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stylish-haskell-0.14.4.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stylish-haskell-0.14.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stylish-haskell
hs-libraries:         HSstylish-haskell-0.14.4.0-E4GUi076jbH3gvW4A0pAPp
depends:
    Cabal-3.8.1.0 HsYAML-0.2.1.3-FekNSkjJemH3qwKowiHdbX
    HsYAML-aeson-0.2.0.1-5qt5VTbcYxuCZqg3UcCNsr
    aeson-2.1.2.1-GOr0sGsn8HVJzt9KhewtB0 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    file-embed-0.0.15.0-7OnjuFj6gBM9fqBKJCVXdU filepath-1.4.2.2
    ghc-9.4.8 ghc-boot-9.4.8 ghc-boot-th-9.4.8
    ghc-lib-parser-ex-9.4.0.0-AbeI4S5LLDg2yKJJHGUqPb mtl-2.2.2
    regex-tdfa-1.3.2.4-DyGMbh1NpFc9rSkmhAEdJe
    syb-0.7.2.4-HJAbU0lurQkHN7nU4EHwhb text-2.0.2

haddock-interfaces:   /usr/share/doc/stylish-haskell/html/stylish-haskell.haddock
haddock-html:         /usr/share/doc/stylish-haskell/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
